# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_spot_exchange_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_spot_exchange_rpc.proto',
  package='injective_spot_exchange_rpc',
  syntax='proto3',
  serialized_options=b'Z\036/injective_spot_exchange_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*exchange/injective_spot_exchange_rpc.proto\x12\x1binjective_spot_exchange_rpc\"P\n\x0eMarketsRequest\x12\x15\n\rmarket_status\x18\x01 \x01(\t\x12\x12\n\nbase_denom\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\"O\n\x0fMarketsResponse\x12<\n\x07markets\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfo\"\x81\x03\n\x0eSpotMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rmarket_status\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x12\n\nbase_denom\x18\x04 \x01(\t\x12?\n\x0f\x62\x61se_token_meta\x18\x05 \x01(\x0b\x32&.injective_spot_exchange_rpc.TokenMeta\x12\x13\n\x0bquote_denom\x18\x06 \x01(\t\x12@\n\x10quote_token_meta\x18\x07 \x01(\x0b\x32&.injective_spot_exchange_rpc.TokenMeta\x12\x16\n\x0emaker_fee_rate\x18\x08 \x01(\t\x12\x16\n\x0etaker_fee_rate\x18\t \x01(\t\x12\x1c\n\x14service_provider_fee\x18\n \x01(\t\x12\x1b\n\x13min_price_tick_size\x18\x0b \x01(\t\x12\x1e\n\x16min_quantity_tick_size\x18\x0c \x01(\t\"n\n\tTokenMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"\"\n\rMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"M\n\x0eMarketResponse\x12;\n\x06market\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfo\"*\n\x14StreamMarketsRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"\x7f\n\x15StreamMarketsResponse\x12;\n\x06market\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotMarketInfo\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"%\n\x10OrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"W\n\x11OrderbookResponse\x12\x42\n\torderbook\x18\x01 \x01(\x0b\x32/.injective_spot_exchange_rpc.SpotLimitOrderbook\"\x83\x01\n\x12SpotLimitOrderbook\x12\x35\n\x04\x62uys\x18\x01 \x03(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevel\x12\x36\n\x05sells\x18\x02 \x03(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevel\"@\n\nPriceLevel\x12\r\n\x05price\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\'\n\x11OrderbooksRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"_\n\x12OrderbooksResponse\x12I\n\norderbooks\x18\x01 \x03(\x0b\x32\x35.injective_spot_exchange_rpc.SingleSpotLimitOrderbook\"q\n\x18SingleSpotLimitOrderbook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x42\n\torderbook\x18\x02 \x01(\x0b\x32/.injective_spot_exchange_rpc.SpotLimitOrderbook\",\n\x16StreamOrderbookRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"\x9b\x01\n\x17StreamOrderbookResponse\x12\x42\n\torderbook\x18\x01 \x01(\x0b\x32/.injective_spot_exchange_rpc.SpotLimitOrderbook\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x12\x11\n\tmarket_id\x18\x04 \x01(\t\"\xbe\x01\n\rOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x12\n\nmarket_ids\x18\x08 \x03(\t\x12\x18\n\x10include_inactive\x18\t \x01(\x08\"\x82\x01\n\x0eOrdersResponse\x12;\n\x06orders\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrder\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\x83\x02\n\x0eSpotLimitOrder\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x10\n\x08quantity\x18\x06 \x01(\t\x12\x19\n\x11unfilled_quantity\x18\x07 \x01(\t\x12\x15\n\rtrigger_price\x18\x08 \x01(\t\x12\x15\n\rfee_recipient\x18\t \x01(\t\x12\r\n\x05state\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\x12\x12\x12\n\nupdated_at\x18\x0c \x01(\x12\"1\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\"\xc4\x01\n\x13StreamOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x12\n\norder_side\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x12\n\nmarket_ids\x18\x08 \x03(\t\x12\x18\n\x10include_inactive\x18\t \x01(\x08\"}\n\x14StreamOrdersResponse\x12:\n\x05order\x18\x01 \x01(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrder\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\xec\x01\n\rTradesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xecution_side\x18\x02 \x01(\t\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\x12\n\nmarket_ids\x18\t \x03(\t\x12\x16\n\x0esubaccount_ids\x18\n \x03(\t\x12\x17\n\x0f\x65xecution_types\x18\x0b \x03(\t\"}\n\x0eTradesResponse\x12\x36\n\x06trades\x18\x01 \x03(\x0b\x32&.injective_spot_exchange_rpc.SpotTrade\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\x83\x02\n\tSpotTrade\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x1c\n\x14trade_execution_type\x18\x04 \x01(\t\x12\x17\n\x0ftrade_direction\x18\x05 \x01(\t\x12\x36\n\x05price\x18\x06 \x01(\x0b\x32\'.injective_spot_exchange_rpc.PriceLevel\x12\x0b\n\x03\x66\x65\x65\x18\x07 \x01(\t\x12\x13\n\x0b\x65xecuted_at\x18\x08 \x01(\x12\x12\x15\n\rfee_recipient\x18\t \x01(\t\x12\x10\n\x08trade_id\x18\n \x01(\t\"\xf2\x01\n\x13StreamTradesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xecution_side\x18\x02 \x01(\t\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\x12\n\nmarket_ids\x18\t \x03(\t\x12\x16\n\x0esubaccount_ids\x18\n \x03(\t\x12\x17\n\x0f\x65xecution_types\x18\x0b \x03(\t\"x\n\x14StreamTradesResponse\x12\x35\n\x05trade\x18\x01 \x01(\x0b\x32&.injective_spot_exchange_rpc.SpotTrade\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"d\n\x1bSubaccountOrdersListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\"\x90\x01\n\x1cSubaccountOrdersListResponse\x12;\n\x06orders\x18\x01 \x03(\x0b\x32+.injective_spot_exchange_rpc.SpotLimitOrder\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\x8f\x01\n\x1bSubaccountTradesListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x03 \x01(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\r\n\x05limit\x18\x06 \x01(\x11\"V\n\x1cSubaccountTradesListResponse\x12\x36\n\x06trades\x18\x01 \x03(\x0b\x32&.injective_spot_exchange_rpc.SpotTrade\"\xd3\x01\n\x14OrdersHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x13\n\x0border_types\x18\x05 \x03(\t\x12\x11\n\tdirection\x18\x06 \x01(\t\x12\x12\n\nstart_time\x18\x07 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x08 \x01(\x12\x12\r\n\x05state\x18\t \x01(\t\x12\x17\n\x0f\x65xecution_types\x18\n \x03(\t\"\x8b\x01\n\x15OrdersHistoryResponse\x12=\n\x06orders\x18\x01 \x03(\x0b\x32-.injective_spot_exchange_rpc.SpotOrderHistory\x12\x33\n\x06paging\x18\x02 \x01(\x0b\x32#.injective_spot_exchange_rpc.Paging\"\xaa\x02\n\x10SpotOrderHistory\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_type\x18\x05 \x01(\t\x12\x12\n\norder_type\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\t\x12\x15\n\rtrigger_price\x18\x08 \x01(\t\x12\x10\n\x08quantity\x18\t \x01(\t\x12\x17\n\x0f\x66illed_quantity\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\x12\x12\x12\n\nupdated_at\x18\r \x01(\x12\x12\x11\n\tdirection\x18\x0e \x01(\t\"\x96\x01\n\x1aStreamOrdersHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x13\n\x0border_types\x18\x03 \x03(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x17\n\x0f\x65xecution_types\x18\x06 \x03(\t\"\x86\x01\n\x1bStreamOrdersHistoryResponse\x12<\n\x05order\x18\x01 \x01(\x0b\x32-.injective_spot_exchange_rpc.SpotOrderHistory\x12\x16\n\x0eoperation_type\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\x32\x8d\r\n\x18InjectiveSpotExchangeRPC\x12\x64\n\x07Markets\x12+.injective_spot_exchange_rpc.MarketsRequest\x1a,.injective_spot_exchange_rpc.MarketsResponse\x12\x61\n\x06Market\x12*.injective_spot_exchange_rpc.MarketRequest\x1a+.injective_spot_exchange_rpc.MarketResponse\x12x\n\rStreamMarkets\x12\x31.injective_spot_exchange_rpc.StreamMarketsRequest\x1a\x32.injective_spot_exchange_rpc.StreamMarketsResponse0\x01\x12j\n\tOrderbook\x12-.injective_spot_exchange_rpc.OrderbookRequest\x1a..injective_spot_exchange_rpc.OrderbookResponse\x12m\n\nOrderbooks\x12..injective_spot_exchange_rpc.OrderbooksRequest\x1a/.injective_spot_exchange_rpc.OrderbooksResponse\x12~\n\x0fStreamOrderbook\x12\x33.injective_spot_exchange_rpc.StreamOrderbookRequest\x1a\x34.injective_spot_exchange_rpc.StreamOrderbookResponse0\x01\x12\x61\n\x06Orders\x12*.injective_spot_exchange_rpc.OrdersRequest\x1a+.injective_spot_exchange_rpc.OrdersResponse\x12u\n\x0cStreamOrders\x12\x30.injective_spot_exchange_rpc.StreamOrdersRequest\x1a\x31.injective_spot_exchange_rpc.StreamOrdersResponse0\x01\x12\x61\n\x06Trades\x12*.injective_spot_exchange_rpc.TradesRequest\x1a+.injective_spot_exchange_rpc.TradesResponse\x12u\n\x0cStreamTrades\x12\x30.injective_spot_exchange_rpc.StreamTradesRequest\x1a\x31.injective_spot_exchange_rpc.StreamTradesResponse0\x01\x12\x8b\x01\n\x14SubaccountOrdersList\x12\x38.injective_spot_exchange_rpc.SubaccountOrdersListRequest\x1a\x39.injective_spot_exchange_rpc.SubaccountOrdersListResponse\x12\x8b\x01\n\x14SubaccountTradesList\x12\x38.injective_spot_exchange_rpc.SubaccountTradesListRequest\x1a\x39.injective_spot_exchange_rpc.SubaccountTradesListResponse\x12v\n\rOrdersHistory\x12\x31.injective_spot_exchange_rpc.OrdersHistoryRequest\x1a\x32.injective_spot_exchange_rpc.OrdersHistoryResponse\x12\x8a\x01\n\x13StreamOrdersHistory\x12\x37.injective_spot_exchange_rpc.StreamOrdersHistoryRequest\x1a\x38.injective_spot_exchange_rpc.StreamOrdersHistoryResponse0\x01\x42 Z\x1e/injective_spot_exchange_rpcpbb\x06proto3'
)




_MARKETSREQUEST = _descriptor.Descriptor(
  name='MarketsRequest',
  full_name='injective_spot_exchange_rpc.MarketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_status', full_name='injective_spot_exchange_rpc.MarketsRequest.market_status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_denom', full_name='injective_spot_exchange_rpc.MarketsRequest.base_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective_spot_exchange_rpc.MarketsRequest.quote_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=155,
)


_MARKETSRESPONSE = _descriptor.Descriptor(
  name='MarketsResponse',
  full_name='injective_spot_exchange_rpc.MarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markets', full_name='injective_spot_exchange_rpc.MarketsResponse.markets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=236,
)


_SPOTMARKETINFO = _descriptor.Descriptor(
  name='SpotMarketInfo',
  full_name='injective_spot_exchange_rpc.SpotMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.SpotMarketInfo.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_status', full_name='injective_spot_exchange_rpc.SpotMarketInfo.market_status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective_spot_exchange_rpc.SpotMarketInfo.ticker', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_denom', full_name='injective_spot_exchange_rpc.SpotMarketInfo.base_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_token_meta', full_name='injective_spot_exchange_rpc.SpotMarketInfo.base_token_meta', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective_spot_exchange_rpc.SpotMarketInfo.quote_denom', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_token_meta', full_name='injective_spot_exchange_rpc.SpotMarketInfo.quote_token_meta', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective_spot_exchange_rpc.SpotMarketInfo.maker_fee_rate', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective_spot_exchange_rpc.SpotMarketInfo.taker_fee_rate', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_provider_fee', full_name='injective_spot_exchange_rpc.SpotMarketInfo.service_provider_fee', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective_spot_exchange_rpc.SpotMarketInfo.min_price_tick_size', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective_spot_exchange_rpc.SpotMarketInfo.min_quantity_tick_size', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=624,
)


_TOKENMETA = _descriptor.Descriptor(
  name='TokenMeta',
  full_name='injective_spot_exchange_rpc.TokenMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='injective_spot_exchange_rpc.TokenMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='injective_spot_exchange_rpc.TokenMeta.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective_spot_exchange_rpc.TokenMeta.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logo', full_name='injective_spot_exchange_rpc.TokenMeta.logo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective_spot_exchange_rpc.TokenMeta.decimals', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_spot_exchange_rpc.TokenMeta.updated_at', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=736,
)


_MARKETREQUEST = _descriptor.Descriptor(
  name='MarketRequest',
  full_name='injective_spot_exchange_rpc.MarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.MarketRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=772,
)


_MARKETRESPONSE = _descriptor.Descriptor(
  name='MarketResponse',
  full_name='injective_spot_exchange_rpc.MarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective_spot_exchange_rpc.MarketResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=851,
)


_STREAMMARKETSREQUEST = _descriptor.Descriptor(
  name='StreamMarketsRequest',
  full_name='injective_spot_exchange_rpc.StreamMarketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_spot_exchange_rpc.StreamMarketsRequest.market_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=895,
)


_STREAMMARKETSRESPONSE = _descriptor.Descriptor(
  name='StreamMarketsResponse',
  full_name='injective_spot_exchange_rpc.StreamMarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective_spot_exchange_rpc.StreamMarketsResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_spot_exchange_rpc.StreamMarketsResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_spot_exchange_rpc.StreamMarketsResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=1024,
)


_ORDERBOOKREQUEST = _descriptor.Descriptor(
  name='OrderbookRequest',
  full_name='injective_spot_exchange_rpc.OrderbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.OrderbookRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1063,
)


_ORDERBOOKRESPONSE = _descriptor.Descriptor(
  name='OrderbookResponse',
  full_name='injective_spot_exchange_rpc.OrderbookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderbook', full_name='injective_spot_exchange_rpc.OrderbookResponse.orderbook', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1152,
)


_SPOTLIMITORDERBOOK = _descriptor.Descriptor(
  name='SpotLimitOrderbook',
  full_name='injective_spot_exchange_rpc.SpotLimitOrderbook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buys', full_name='injective_spot_exchange_rpc.SpotLimitOrderbook.buys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sells', full_name='injective_spot_exchange_rpc.SpotLimitOrderbook.sells', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1286,
)


_PRICELEVEL = _descriptor.Descriptor(
  name='PriceLevel',
  full_name='injective_spot_exchange_rpc.PriceLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_spot_exchange_rpc.PriceLevel.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective_spot_exchange_rpc.PriceLevel.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_spot_exchange_rpc.PriceLevel.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1352,
)


_ORDERBOOKSREQUEST = _descriptor.Descriptor(
  name='OrderbooksRequest',
  full_name='injective_spot_exchange_rpc.OrderbooksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_spot_exchange_rpc.OrderbooksRequest.market_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1393,
)


_ORDERBOOKSRESPONSE = _descriptor.Descriptor(
  name='OrderbooksResponse',
  full_name='injective_spot_exchange_rpc.OrderbooksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderbooks', full_name='injective_spot_exchange_rpc.OrderbooksResponse.orderbooks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1490,
)


_SINGLESPOTLIMITORDERBOOK = _descriptor.Descriptor(
  name='SingleSpotLimitOrderbook',
  full_name='injective_spot_exchange_rpc.SingleSpotLimitOrderbook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.SingleSpotLimitOrderbook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderbook', full_name='injective_spot_exchange_rpc.SingleSpotLimitOrderbook.orderbook', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1492,
  serialized_end=1605,
)


_STREAMORDERBOOKREQUEST = _descriptor.Descriptor(
  name='StreamOrderbookRequest',
  full_name='injective_spot_exchange_rpc.StreamOrderbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_spot_exchange_rpc.StreamOrderbookRequest.market_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1607,
  serialized_end=1651,
)


_STREAMORDERBOOKRESPONSE = _descriptor.Descriptor(
  name='StreamOrderbookResponse',
  full_name='injective_spot_exchange_rpc.StreamOrderbookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderbook', full_name='injective_spot_exchange_rpc.StreamOrderbookResponse.orderbook', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_spot_exchange_rpc.StreamOrderbookResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_spot_exchange_rpc.StreamOrderbookResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.StreamOrderbookResponse.market_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1809,
)


_ORDERSREQUEST = _descriptor.Descriptor(
  name='OrdersRequest',
  full_name='injective_spot_exchange_rpc.OrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.OrdersRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_side', full_name='injective_spot_exchange_rpc.OrdersRequest.order_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.OrdersRequest.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_spot_exchange_rpc.OrdersRequest.skip', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_spot_exchange_rpc.OrdersRequest.limit', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_spot_exchange_rpc.OrdersRequest.start_time', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_spot_exchange_rpc.OrdersRequest.end_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_spot_exchange_rpc.OrdersRequest.market_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_inactive', full_name='injective_spot_exchange_rpc.OrdersRequest.include_inactive', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1812,
  serialized_end=2002,
)


_ORDERSRESPONSE = _descriptor.Descriptor(
  name='OrdersResponse',
  full_name='injective_spot_exchange_rpc.OrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective_spot_exchange_rpc.OrdersResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_spot_exchange_rpc.OrdersResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2135,
)


_SPOTLIMITORDER = _descriptor.Descriptor(
  name='SpotLimitOrder',
  full_name='injective_spot_exchange_rpc.SpotLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective_spot_exchange_rpc.SpotLimitOrder.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_side', full_name='injective_spot_exchange_rpc.SpotLimitOrder.order_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.SpotLimitOrder.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.SpotLimitOrder.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_spot_exchange_rpc.SpotLimitOrder.price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective_spot_exchange_rpc.SpotLimitOrder.quantity', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unfilled_quantity', full_name='injective_spot_exchange_rpc.SpotLimitOrder.unfilled_quantity', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective_spot_exchange_rpc.SpotLimitOrder.trigger_price', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_recipient', full_name='injective_spot_exchange_rpc.SpotLimitOrder.fee_recipient', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_spot_exchange_rpc.SpotLimitOrder.state', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='injective_spot_exchange_rpc.SpotLimitOrder.created_at', index=10,
      number=11, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_spot_exchange_rpc.SpotLimitOrder.updated_at', index=11,
      number=12, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2138,
  serialized_end=2397,
)


_PAGING = _descriptor.Descriptor(
  name='Paging',
  full_name='injective_spot_exchange_rpc.Paging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='injective_spot_exchange_rpc.Paging.total', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='injective_spot_exchange_rpc.Paging.from', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='injective_spot_exchange_rpc.Paging.to', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2399,
  serialized_end=2448,
)


_STREAMORDERSREQUEST = _descriptor.Descriptor(
  name='StreamOrdersRequest',
  full_name='injective_spot_exchange_rpc.StreamOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_side', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.order_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.subaccount_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.skip', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.limit', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.start_time', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.end_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.market_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_inactive', full_name='injective_spot_exchange_rpc.StreamOrdersRequest.include_inactive', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2451,
  serialized_end=2647,
)


_STREAMORDERSRESPONSE = _descriptor.Descriptor(
  name='StreamOrdersResponse',
  full_name='injective_spot_exchange_rpc.StreamOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='injective_spot_exchange_rpc.StreamOrdersResponse.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_spot_exchange_rpc.StreamOrdersResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_spot_exchange_rpc.StreamOrdersResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2649,
  serialized_end=2774,
)


_TRADESREQUEST = _descriptor.Descriptor(
  name='TradesRequest',
  full_name='injective_spot_exchange_rpc.TradesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.TradesRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_side', full_name='injective_spot_exchange_rpc.TradesRequest.execution_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_spot_exchange_rpc.TradesRequest.direction', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.TradesRequest.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_spot_exchange_rpc.TradesRequest.skip', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_spot_exchange_rpc.TradesRequest.limit', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_spot_exchange_rpc.TradesRequest.start_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_spot_exchange_rpc.TradesRequest.end_time', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_spot_exchange_rpc.TradesRequest.market_ids', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_ids', full_name='injective_spot_exchange_rpc.TradesRequest.subaccount_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_spot_exchange_rpc.TradesRequest.execution_types', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2777,
  serialized_end=3013,
)


_TRADESRESPONSE = _descriptor.Descriptor(
  name='TradesResponse',
  full_name='injective_spot_exchange_rpc.TradesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective_spot_exchange_rpc.TradesResponse.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_spot_exchange_rpc.TradesResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3015,
  serialized_end=3140,
)


_SPOTTRADE = _descriptor.Descriptor(
  name='SpotTrade',
  full_name='injective_spot_exchange_rpc.SpotTrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective_spot_exchange_rpc.SpotTrade.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.SpotTrade.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.SpotTrade.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_execution_type', full_name='injective_spot_exchange_rpc.SpotTrade.trade_execution_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_direction', full_name='injective_spot_exchange_rpc.SpotTrade.trade_direction', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_spot_exchange_rpc.SpotTrade.price', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='injective_spot_exchange_rpc.SpotTrade.fee', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executed_at', full_name='injective_spot_exchange_rpc.SpotTrade.executed_at', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_recipient', full_name='injective_spot_exchange_rpc.SpotTrade.fee_recipient', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_id', full_name='injective_spot_exchange_rpc.SpotTrade.trade_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3143,
  serialized_end=3402,
)


_STREAMTRADESREQUEST = _descriptor.Descriptor(
  name='StreamTradesRequest',
  full_name='injective_spot_exchange_rpc.StreamTradesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.StreamTradesRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_side', full_name='injective_spot_exchange_rpc.StreamTradesRequest.execution_side', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_spot_exchange_rpc.StreamTradesRequest.direction', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.StreamTradesRequest.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_spot_exchange_rpc.StreamTradesRequest.skip', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_spot_exchange_rpc.StreamTradesRequest.limit', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_spot_exchange_rpc.StreamTradesRequest.start_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_spot_exchange_rpc.StreamTradesRequest.end_time', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective_spot_exchange_rpc.StreamTradesRequest.market_ids', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_ids', full_name='injective_spot_exchange_rpc.StreamTradesRequest.subaccount_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_spot_exchange_rpc.StreamTradesRequest.execution_types', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3405,
  serialized_end=3647,
)


_STREAMTRADESRESPONSE = _descriptor.Descriptor(
  name='StreamTradesResponse',
  full_name='injective_spot_exchange_rpc.StreamTradesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade', full_name='injective_spot_exchange_rpc.StreamTradesResponse.trade', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_spot_exchange_rpc.StreamTradesResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_spot_exchange_rpc.StreamTradesResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3649,
  serialized_end=3769,
)


_SUBACCOUNTORDERSLISTREQUEST = _descriptor.Descriptor(
  name='SubaccountOrdersListRequest',
  full_name='injective_spot_exchange_rpc.SubaccountOrdersListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.SubaccountOrdersListRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.SubaccountOrdersListRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_spot_exchange_rpc.SubaccountOrdersListRequest.skip', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_spot_exchange_rpc.SubaccountOrdersListRequest.limit', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3771,
  serialized_end=3871,
)


_SUBACCOUNTORDERSLISTRESPONSE = _descriptor.Descriptor(
  name='SubaccountOrdersListResponse',
  full_name='injective_spot_exchange_rpc.SubaccountOrdersListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective_spot_exchange_rpc.SubaccountOrdersListResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_spot_exchange_rpc.SubaccountOrdersListResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3874,
  serialized_end=4018,
)


_SUBACCOUNTTRADESLISTREQUEST = _descriptor.Descriptor(
  name='SubaccountTradesListRequest',
  full_name='injective_spot_exchange_rpc.SubaccountTradesListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.SubaccountTradesListRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.SubaccountTradesListRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_type', full_name='injective_spot_exchange_rpc.SubaccountTradesListRequest.execution_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_spot_exchange_rpc.SubaccountTradesListRequest.direction', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_spot_exchange_rpc.SubaccountTradesListRequest.skip', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_spot_exchange_rpc.SubaccountTradesListRequest.limit', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4021,
  serialized_end=4164,
)


_SUBACCOUNTTRADESLISTRESPONSE = _descriptor.Descriptor(
  name='SubaccountTradesListResponse',
  full_name='injective_spot_exchange_rpc.SubaccountTradesListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective_spot_exchange_rpc.SubaccountTradesListResponse.trades', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4166,
  serialized_end=4252,
)


_ORDERSHISTORYREQUEST = _descriptor.Descriptor(
  name='OrdersHistoryRequest',
  full_name='injective_spot_exchange_rpc.OrdersHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.skip', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.limit', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_types', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.order_types', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.direction', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.start_time', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.end_time', index=7,
      number=8, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.state', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_spot_exchange_rpc.OrdersHistoryRequest.execution_types', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4255,
  serialized_end=4466,
)


_ORDERSHISTORYRESPONSE = _descriptor.Descriptor(
  name='OrdersHistoryResponse',
  full_name='injective_spot_exchange_rpc.OrdersHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective_spot_exchange_rpc.OrdersHistoryResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_spot_exchange_rpc.OrdersHistoryResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4469,
  serialized_end=4608,
)


_SPOTORDERHISTORY = _descriptor.Descriptor(
  name='SpotOrderHistory',
  full_name='injective_spot_exchange_rpc.SpotOrderHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective_spot_exchange_rpc.SpotOrderHistory.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.SpotOrderHistory.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='injective_spot_exchange_rpc.SpotOrderHistory.is_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.SpotOrderHistory.subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_type', full_name='injective_spot_exchange_rpc.SpotOrderHistory.execution_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective_spot_exchange_rpc.SpotOrderHistory.order_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_spot_exchange_rpc.SpotOrderHistory.price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective_spot_exchange_rpc.SpotOrderHistory.trigger_price', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective_spot_exchange_rpc.SpotOrderHistory.quantity', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filled_quantity', full_name='injective_spot_exchange_rpc.SpotOrderHistory.filled_quantity', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_spot_exchange_rpc.SpotOrderHistory.state', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='injective_spot_exchange_rpc.SpotOrderHistory.created_at', index=11,
      number=12, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_spot_exchange_rpc.SpotOrderHistory.updated_at', index=12,
      number=13, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_spot_exchange_rpc.SpotOrderHistory.direction', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4611,
  serialized_end=4909,
)


_STREAMORDERSHISTORYREQUEST = _descriptor.Descriptor(
  name='StreamOrdersHistoryRequest',
  full_name='injective_spot_exchange_rpc.StreamOrdersHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_types', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryRequest.order_types', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryRequest.direction', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryRequest.state', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_types', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryRequest.execution_types', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4912,
  serialized_end=5062,
)


_STREAMORDERSHISTORYRESPONSE = _descriptor.Descriptor(
  name='StreamOrdersHistoryResponse',
  full_name='injective_spot_exchange_rpc.StreamOrdersHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryResponse.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_type', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryResponse.operation_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_spot_exchange_rpc.StreamOrdersHistoryResponse.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5065,
  serialized_end=5199,
)

_MARKETSRESPONSE.fields_by_name['markets'].message_type = _SPOTMARKETINFO
_SPOTMARKETINFO.fields_by_name['base_token_meta'].message_type = _TOKENMETA
_SPOTMARKETINFO.fields_by_name['quote_token_meta'].message_type = _TOKENMETA
_MARKETRESPONSE.fields_by_name['market'].message_type = _SPOTMARKETINFO
_STREAMMARKETSRESPONSE.fields_by_name['market'].message_type = _SPOTMARKETINFO
_ORDERBOOKRESPONSE.fields_by_name['orderbook'].message_type = _SPOTLIMITORDERBOOK
_SPOTLIMITORDERBOOK.fields_by_name['buys'].message_type = _PRICELEVEL
_SPOTLIMITORDERBOOK.fields_by_name['sells'].message_type = _PRICELEVEL
_ORDERBOOKSRESPONSE.fields_by_name['orderbooks'].message_type = _SINGLESPOTLIMITORDERBOOK
_SINGLESPOTLIMITORDERBOOK.fields_by_name['orderbook'].message_type = _SPOTLIMITORDERBOOK
_STREAMORDERBOOKRESPONSE.fields_by_name['orderbook'].message_type = _SPOTLIMITORDERBOOK
_ORDERSRESPONSE.fields_by_name['orders'].message_type = _SPOTLIMITORDER
_ORDERSRESPONSE.fields_by_name['paging'].message_type = _PAGING
_STREAMORDERSRESPONSE.fields_by_name['order'].message_type = _SPOTLIMITORDER
_TRADESRESPONSE.fields_by_name['trades'].message_type = _SPOTTRADE
_TRADESRESPONSE.fields_by_name['paging'].message_type = _PAGING
_SPOTTRADE.fields_by_name['price'].message_type = _PRICELEVEL
_STREAMTRADESRESPONSE.fields_by_name['trade'].message_type = _SPOTTRADE
_SUBACCOUNTORDERSLISTRESPONSE.fields_by_name['orders'].message_type = _SPOTLIMITORDER
_SUBACCOUNTORDERSLISTRESPONSE.fields_by_name['paging'].message_type = _PAGING
_SUBACCOUNTTRADESLISTRESPONSE.fields_by_name['trades'].message_type = _SPOTTRADE
_ORDERSHISTORYRESPONSE.fields_by_name['orders'].message_type = _SPOTORDERHISTORY
_ORDERSHISTORYRESPONSE.fields_by_name['paging'].message_type = _PAGING
_STREAMORDERSHISTORYRESPONSE.fields_by_name['order'].message_type = _SPOTORDERHISTORY
DESCRIPTOR.message_types_by_name['MarketsRequest'] = _MARKETSREQUEST
DESCRIPTOR.message_types_by_name['MarketsResponse'] = _MARKETSRESPONSE
DESCRIPTOR.message_types_by_name['SpotMarketInfo'] = _SPOTMARKETINFO
DESCRIPTOR.message_types_by_name['TokenMeta'] = _TOKENMETA
DESCRIPTOR.message_types_by_name['MarketRequest'] = _MARKETREQUEST
DESCRIPTOR.message_types_by_name['MarketResponse'] = _MARKETRESPONSE
DESCRIPTOR.message_types_by_name['StreamMarketsRequest'] = _STREAMMARKETSREQUEST
DESCRIPTOR.message_types_by_name['StreamMarketsResponse'] = _STREAMMARKETSRESPONSE
DESCRIPTOR.message_types_by_name['OrderbookRequest'] = _ORDERBOOKREQUEST
DESCRIPTOR.message_types_by_name['OrderbookResponse'] = _ORDERBOOKRESPONSE
DESCRIPTOR.message_types_by_name['SpotLimitOrderbook'] = _SPOTLIMITORDERBOOK
DESCRIPTOR.message_types_by_name['PriceLevel'] = _PRICELEVEL
DESCRIPTOR.message_types_by_name['OrderbooksRequest'] = _ORDERBOOKSREQUEST
DESCRIPTOR.message_types_by_name['OrderbooksResponse'] = _ORDERBOOKSRESPONSE
DESCRIPTOR.message_types_by_name['SingleSpotLimitOrderbook'] = _SINGLESPOTLIMITORDERBOOK
DESCRIPTOR.message_types_by_name['StreamOrderbookRequest'] = _STREAMORDERBOOKREQUEST
DESCRIPTOR.message_types_by_name['StreamOrderbookResponse'] = _STREAMORDERBOOKRESPONSE
DESCRIPTOR.message_types_by_name['OrdersRequest'] = _ORDERSREQUEST
DESCRIPTOR.message_types_by_name['OrdersResponse'] = _ORDERSRESPONSE
DESCRIPTOR.message_types_by_name['SpotLimitOrder'] = _SPOTLIMITORDER
DESCRIPTOR.message_types_by_name['Paging'] = _PAGING
DESCRIPTOR.message_types_by_name['StreamOrdersRequest'] = _STREAMORDERSREQUEST
DESCRIPTOR.message_types_by_name['StreamOrdersResponse'] = _STREAMORDERSRESPONSE
DESCRIPTOR.message_types_by_name['TradesRequest'] = _TRADESREQUEST
DESCRIPTOR.message_types_by_name['TradesResponse'] = _TRADESRESPONSE
DESCRIPTOR.message_types_by_name['SpotTrade'] = _SPOTTRADE
DESCRIPTOR.message_types_by_name['StreamTradesRequest'] = _STREAMTRADESREQUEST
DESCRIPTOR.message_types_by_name['StreamTradesResponse'] = _STREAMTRADESRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountOrdersListRequest'] = _SUBACCOUNTORDERSLISTREQUEST
DESCRIPTOR.message_types_by_name['SubaccountOrdersListResponse'] = _SUBACCOUNTORDERSLISTRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountTradesListRequest'] = _SUBACCOUNTTRADESLISTREQUEST
DESCRIPTOR.message_types_by_name['SubaccountTradesListResponse'] = _SUBACCOUNTTRADESLISTRESPONSE
DESCRIPTOR.message_types_by_name['OrdersHistoryRequest'] = _ORDERSHISTORYREQUEST
DESCRIPTOR.message_types_by_name['OrdersHistoryResponse'] = _ORDERSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['SpotOrderHistory'] = _SPOTORDERHISTORY
DESCRIPTOR.message_types_by_name['StreamOrdersHistoryRequest'] = _STREAMORDERSHISTORYREQUEST
DESCRIPTOR.message_types_by_name['StreamOrdersHistoryResponse'] = _STREAMORDERSHISTORYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketsRequest = _reflection.GeneratedProtocolMessageType('MarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.MarketsRequest)
  })
_sym_db.RegisterMessage(MarketsRequest)

MarketsResponse = _reflection.GeneratedProtocolMessageType('MarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.MarketsResponse)
  })
_sym_db.RegisterMessage(MarketsResponse)

SpotMarketInfo = _reflection.GeneratedProtocolMessageType('SpotMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _SPOTMARKETINFO,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SpotMarketInfo)
  })
_sym_db.RegisterMessage(SpotMarketInfo)

TokenMeta = _reflection.GeneratedProtocolMessageType('TokenMeta', (_message.Message,), {
  'DESCRIPTOR' : _TOKENMETA,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.TokenMeta)
  })
_sym_db.RegisterMessage(TokenMeta)

MarketRequest = _reflection.GeneratedProtocolMessageType('MarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.MarketRequest)
  })
_sym_db.RegisterMessage(MarketRequest)

MarketResponse = _reflection.GeneratedProtocolMessageType('MarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.MarketResponse)
  })
_sym_db.RegisterMessage(MarketResponse)

StreamMarketsRequest = _reflection.GeneratedProtocolMessageType('StreamMarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETSREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamMarketsRequest)
  })
_sym_db.RegisterMessage(StreamMarketsRequest)

StreamMarketsResponse = _reflection.GeneratedProtocolMessageType('StreamMarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMMARKETSRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamMarketsResponse)
  })
_sym_db.RegisterMessage(StreamMarketsResponse)

OrderbookRequest = _reflection.GeneratedProtocolMessageType('OrderbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrderbookRequest)
  })
_sym_db.RegisterMessage(OrderbookRequest)

OrderbookResponse = _reflection.GeneratedProtocolMessageType('OrderbookResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrderbookResponse)
  })
_sym_db.RegisterMessage(OrderbookResponse)

SpotLimitOrderbook = _reflection.GeneratedProtocolMessageType('SpotLimitOrderbook', (_message.Message,), {
  'DESCRIPTOR' : _SPOTLIMITORDERBOOK,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SpotLimitOrderbook)
  })
_sym_db.RegisterMessage(SpotLimitOrderbook)

PriceLevel = _reflection.GeneratedProtocolMessageType('PriceLevel', (_message.Message,), {
  'DESCRIPTOR' : _PRICELEVEL,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.PriceLevel)
  })
_sym_db.RegisterMessage(PriceLevel)

OrderbooksRequest = _reflection.GeneratedProtocolMessageType('OrderbooksRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKSREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrderbooksRequest)
  })
_sym_db.RegisterMessage(OrderbooksRequest)

OrderbooksResponse = _reflection.GeneratedProtocolMessageType('OrderbooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERBOOKSRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrderbooksResponse)
  })
_sym_db.RegisterMessage(OrderbooksResponse)

SingleSpotLimitOrderbook = _reflection.GeneratedProtocolMessageType('SingleSpotLimitOrderbook', (_message.Message,), {
  'DESCRIPTOR' : _SINGLESPOTLIMITORDERBOOK,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SingleSpotLimitOrderbook)
  })
_sym_db.RegisterMessage(SingleSpotLimitOrderbook)

StreamOrderbookRequest = _reflection.GeneratedProtocolMessageType('StreamOrderbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERBOOKREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamOrderbookRequest)
  })
_sym_db.RegisterMessage(StreamOrderbookRequest)

StreamOrderbookResponse = _reflection.GeneratedProtocolMessageType('StreamOrderbookResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERBOOKRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamOrderbookResponse)
  })
_sym_db.RegisterMessage(StreamOrderbookResponse)

OrdersRequest = _reflection.GeneratedProtocolMessageType('OrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrdersRequest)
  })
_sym_db.RegisterMessage(OrdersRequest)

OrdersResponse = _reflection.GeneratedProtocolMessageType('OrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrdersResponse)
  })
_sym_db.RegisterMessage(OrdersResponse)

SpotLimitOrder = _reflection.GeneratedProtocolMessageType('SpotLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _SPOTLIMITORDER,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SpotLimitOrder)
  })
_sym_db.RegisterMessage(SpotLimitOrder)

Paging = _reflection.GeneratedProtocolMessageType('Paging', (_message.Message,), {
  'DESCRIPTOR' : _PAGING,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.Paging)
  })
_sym_db.RegisterMessage(Paging)

StreamOrdersRequest = _reflection.GeneratedProtocolMessageType('StreamOrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamOrdersRequest)
  })
_sym_db.RegisterMessage(StreamOrdersRequest)

StreamOrdersResponse = _reflection.GeneratedProtocolMessageType('StreamOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamOrdersResponse)
  })
_sym_db.RegisterMessage(StreamOrdersResponse)

TradesRequest = _reflection.GeneratedProtocolMessageType('TradesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRADESREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.TradesRequest)
  })
_sym_db.RegisterMessage(TradesRequest)

TradesResponse = _reflection.GeneratedProtocolMessageType('TradesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRADESRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.TradesResponse)
  })
_sym_db.RegisterMessage(TradesResponse)

SpotTrade = _reflection.GeneratedProtocolMessageType('SpotTrade', (_message.Message,), {
  'DESCRIPTOR' : _SPOTTRADE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SpotTrade)
  })
_sym_db.RegisterMessage(SpotTrade)

StreamTradesRequest = _reflection.GeneratedProtocolMessageType('StreamTradesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRADESREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamTradesRequest)
  })
_sym_db.RegisterMessage(StreamTradesRequest)

StreamTradesResponse = _reflection.GeneratedProtocolMessageType('StreamTradesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTRADESRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamTradesResponse)
  })
_sym_db.RegisterMessage(StreamTradesResponse)

SubaccountOrdersListRequest = _reflection.GeneratedProtocolMessageType('SubaccountOrdersListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERSLISTREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SubaccountOrdersListRequest)
  })
_sym_db.RegisterMessage(SubaccountOrdersListRequest)

SubaccountOrdersListResponse = _reflection.GeneratedProtocolMessageType('SubaccountOrdersListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERSLISTRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SubaccountOrdersListResponse)
  })
_sym_db.RegisterMessage(SubaccountOrdersListResponse)

SubaccountTradesListRequest = _reflection.GeneratedProtocolMessageType('SubaccountTradesListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTTRADESLISTREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SubaccountTradesListRequest)
  })
_sym_db.RegisterMessage(SubaccountTradesListRequest)

SubaccountTradesListResponse = _reflection.GeneratedProtocolMessageType('SubaccountTradesListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTTRADESLISTRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SubaccountTradesListResponse)
  })
_sym_db.RegisterMessage(SubaccountTradesListResponse)

OrdersHistoryRequest = _reflection.GeneratedProtocolMessageType('OrdersHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSHISTORYREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrdersHistoryRequest)
  })
_sym_db.RegisterMessage(OrdersHistoryRequest)

OrdersHistoryResponse = _reflection.GeneratedProtocolMessageType('OrdersHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSHISTORYRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.OrdersHistoryResponse)
  })
_sym_db.RegisterMessage(OrdersHistoryResponse)

SpotOrderHistory = _reflection.GeneratedProtocolMessageType('SpotOrderHistory', (_message.Message,), {
  'DESCRIPTOR' : _SPOTORDERHISTORY,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.SpotOrderHistory)
  })
_sym_db.RegisterMessage(SpotOrderHistory)

StreamOrdersHistoryRequest = _reflection.GeneratedProtocolMessageType('StreamOrdersHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSHISTORYREQUEST,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamOrdersHistoryRequest)
  })
_sym_db.RegisterMessage(StreamOrdersHistoryRequest)

StreamOrdersHistoryResponse = _reflection.GeneratedProtocolMessageType('StreamOrdersHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMORDERSHISTORYRESPONSE,
  '__module__' : 'exchange.injective_spot_exchange_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_spot_exchange_rpc.StreamOrdersHistoryResponse)
  })
_sym_db.RegisterMessage(StreamOrdersHistoryResponse)


DESCRIPTOR._options = None

_INJECTIVESPOTEXCHANGERPC = _descriptor.ServiceDescriptor(
  name='InjectiveSpotExchangeRPC',
  full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5202,
  serialized_end=6879,
  methods=[
  _descriptor.MethodDescriptor(
    name='Markets',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.Markets',
    index=0,
    containing_service=None,
    input_type=_MARKETSREQUEST,
    output_type=_MARKETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Market',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.Market',
    index=1,
    containing_service=None,
    input_type=_MARKETREQUEST,
    output_type=_MARKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamMarkets',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.StreamMarkets',
    index=2,
    containing_service=None,
    input_type=_STREAMMARKETSREQUEST,
    output_type=_STREAMMARKETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Orderbook',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.Orderbook',
    index=3,
    containing_service=None,
    input_type=_ORDERBOOKREQUEST,
    output_type=_ORDERBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Orderbooks',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.Orderbooks',
    index=4,
    containing_service=None,
    input_type=_ORDERBOOKSREQUEST,
    output_type=_ORDERBOOKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamOrderbook',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.StreamOrderbook',
    index=5,
    containing_service=None,
    input_type=_STREAMORDERBOOKREQUEST,
    output_type=_STREAMORDERBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Orders',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.Orders',
    index=6,
    containing_service=None,
    input_type=_ORDERSREQUEST,
    output_type=_ORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamOrders',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.StreamOrders',
    index=7,
    containing_service=None,
    input_type=_STREAMORDERSREQUEST,
    output_type=_STREAMORDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Trades',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.Trades',
    index=8,
    containing_service=None,
    input_type=_TRADESREQUEST,
    output_type=_TRADESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamTrades',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.StreamTrades',
    index=9,
    containing_service=None,
    input_type=_STREAMTRADESREQUEST,
    output_type=_STREAMTRADESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountOrdersList',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.SubaccountOrdersList',
    index=10,
    containing_service=None,
    input_type=_SUBACCOUNTORDERSLISTREQUEST,
    output_type=_SUBACCOUNTORDERSLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountTradesList',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.SubaccountTradesList',
    index=11,
    containing_service=None,
    input_type=_SUBACCOUNTTRADESLISTREQUEST,
    output_type=_SUBACCOUNTTRADESLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OrdersHistory',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.OrdersHistory',
    index=12,
    containing_service=None,
    input_type=_ORDERSHISTORYREQUEST,
    output_type=_ORDERSHISTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamOrdersHistory',
    full_name='injective_spot_exchange_rpc.InjectiveSpotExchangeRPC.StreamOrdersHistory',
    index=13,
    containing_service=None,
    input_type=_STREAMORDERSHISTORYREQUEST,
    output_type=_STREAMORDERSHISTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVESPOTEXCHANGERPC)

DESCRIPTOR.services_by_name['InjectiveSpotExchangeRPC'] = _INJECTIVESPOTEXCHANGERPC

# @@protoc_insertion_point(module_scope)
